from optparse import OptionParser
import sys
import os
import logging
import logging.handlers
import time
import ConfigParser

from wheeljack.builder import Builder
from wheeljack import settings

log = logging.getLogger('Wheeljack')
sth = logging.StreamHandler()
sth.setFormatter(logging.Formatter(
        "[%(asctime)s] - %(message)s", "%x %X"))
log.addHandler(sth)
log.setLevel(logging.DEBUG)

def exit_with_error(*messages):
    print ' '.join(messages)
    sys.exit(1)

def show_help(parser):
    parser.print_help()
    sys.exit(1)

def parse_cfg(cfg_path):
    cfg_parser = ConfigParser.ConfigParser()
    cfg_parser.read(cfg_path)
    for section, key, target in [('locations', 'configuration', 'configroot'),
                                 ('builder', 'builder', 'builder'),
                                 ('builder', 'passwd', 'passwd'),
                                 ('builder', 'secret', 'secret'),
                                 ('mail', 'from', 'default_from'),
                                 ('mail', 'smtp-server', 'smtp_server')]:
        setattr(settings, target, cfg_parser.get(section, key))

def build_project(command):
    """This builds a single project based on command line arguments."""
    parser = OptionParser(
        usage=('usage: %prog ' + command + ' project\n'
               'PROJECT is the id of the project'))
    parser.add_option(
        '-f', '--force', dest='force', metavar='MINUTES',
        default=False, action='store_true',
        help='Sleep the specified amount of time in between build runs.')
    parser.add_option('-c', '--configuration', dest='conf',
                      default='/etc/wheeljack.cfg')
    options, args = parser.parse_args()

    if len(args) != 1:
        show_help(parser)

    if not os.path.exists(options.conf):
        exit('Configuration file for Wheeljack does not exist: %s' % options.conf)
    try:
        parse_cfg(options.conf)
    except ConfigParser.Error, e:
        exit('Error reading configuration.', e.message)

    builder = Builder()
    log.info('Starting build')
    print settings.configroot
    from wheeljack import models
    try:
        project = models.Project.load(args[0])
    except KeyError:
        print 'Project: %s does not exists.' % args[0]
        sys.exit(1)
    if options.force:
        project.require_build = True
    if not builder.build(project):
        # Let the process calling us know we failed.
        log.error('Project failed to build')
        sys.exit(1)

def continuous_build(command):
    parser = OptionParser(
        usage='usage: %prog ' + command +' [options] path')
    parser.add_option(
        "-s", "--sleep", dest="sleep", metavar='MINUTES',
        default=60, type="int",
        help="Sleep the specified amount of time in between build runs.")

    options, args = parser.parse_args()

    if len(args) != 1:
        show_help(parser)

    log.info('Starting builds')

    path = os.path.join(_root,'wheeljack.cfg')
    if not os.path.exists(path):
        print 'Missing configuration file for Wheeljack.'
        sys.exit(1)
    try:
        parse_cfg(path)
    except ConfigParser.NoSectionError:
        print 'Missing section in Wheeljack configuration.'
        sys.exit(1)
    except ConfigParser.NoOptionError:
        print 'Missing option in Wheeljack configuration.'
        sys.exit(1)
    
    builder = Builder()

    if command == 'continuous':
        while True:
            builder.build_all()
            time.sleep(options.sleep * 60) # Let the system relax for a bit
    else:
        builder.build_all()

def server(command):
    parser = OptionParser(
        usage='usage: %prog ' + command +' [options]')
    options, args = parser.parse_args()
    log.info('Starting server')
    from wheeljack.views import app
    from wsgiref.simple_server import make_server
    s = make_server('localhost', 8080, app)
    s.serve_forever()

commands = {
    'build': build_project,
    'continuous': continuous_build,
    'build-all': continuous_build,
    'start-server': server,
}

def main():
    from bzrlib.plugin import load_plugins
    load_plugins()
    #server('')
    script = sys.argv[0]
    if len(sys.argv) < 2:
        print 'Usage %s subcommand [options] [args]:' % script
        print ''
        print "Type '%s subcommand --help' for help on a specific subcommand" % script
        print 'Available subcommands:'
        for command in sorted(commands):
            print '  ', command
        sys.exit(1)
    command = sys.argv.pop(1)
    try:
        handler = commands[command]
    except KeyError:
        print "Unknown command: '%s'" % command
        print "Type '%s' for usage" % script
        sys.exit(1)
    handler(command)

if __name__ == '__main__':
    main()
