import unittest
import os

from wheeljack import settings
from wheeljack import scripts

class TestOptionValues(unittest.TestCase):
    """test scripts.parse_cfg()    
    
    """
    keys = ('configroot', 'builder', 'passwd', 'secret', 'default_from', 'smtp_server')

    def setUp(self):
        self.old_settings = [(key, getattr(settings, key)) for key in self.keys]
        scripts.parse_cfg(os.path.join(os.path.dirname(__file__),
                                       'config', 'dummy.cfg'))

    def tearDown(self):
        for key, value in self.old_settings:
            setattr(settings, key, value)

    def test_configroot(self):
        self.assertEqual(settings.configroot, '/some/path/tests/fake-root')

    def test_builder(self):
        cfg_builder = settings.builder
        self.assertEqual(settings.builder, '/some/path/wheeljack')

    def test_passwd(self):
        cfg_passwd = settings.passwd
        self.assertEqual(settings.passwd, 'passwd')

    def test_secret(self):
        cfg_secret = settings.secret
        self.assertEqual(settings.secret, r'M6+0A\FhQfr=FbwkQL_\\aBPDPJS')

    def test_default_from(self):
        cfg_default_from = settings.default_from
        self.assertEqual(settings.default_from , 'wheeljack@cybertron.space' )

    def test_smtp_server(self):
        cfg_smtp_server = settings.smtp_server
        self.assertEqual(settings.smtp_server, 'smtp.cybertron')

def test_suite():
    return unittest.TestSuite([
            unittest.makeSuite(TestOptionValues)
        ])
